
# This file was automatically generated by Dist::Zilla::Plugin::ModuleBuild v6.015.
use strict;
use warnings;

use Module::Build 0.28;


my %module_build_args = (
  "build_requires" => {
    "Module::Build" => "0.28"
  },
  "configure_requires" => {
    "Module::Build" => "0.28"
  },
  "dist_abstract" => "install the CPAN dependencies of the Freecell Solver multi-config test suite.",
  "dist_author" => [
    "Shlomi Fish <shlomif\@cpan.org>"
  ],
  "dist_name" => "Task-FreecellSolver-Testing-MultiConfig",
  "dist_version" => "0.0.4",
  "license" => "mit",
  "module_name" => "Task::FreecellSolver::Testing::MultiConfig",
  "recursive_test_files" => 1,
  "requires" => {
    "App::Deps::Verify" => 0,
    "App::Docmake" => 0,
    "Code::TidyAll::Plugin::ClangFormat" => 0,
    "Code::TidyAll::Plugin::ESLint" => 0,
    "Code::TidyAll::Plugin::TSLint" => 0,
    "Dist::Zilla::Plugin::Test::Kwalitee" => 0,
    "Dist::Zilla::Plugin::Test::TidyAll" => 0,
    "Dist::Zilla::PluginBundle::SHLOMIF" => 0,
    "HTML::Spelling::Site::Whitelist" => 0,
    "HTML::Toc" => 0,
    "HTML::TocGenerator" => 0,
    "Markdent" => 0,
    "Parallel::ForkManager::Segmented" => 0,
    "Perl::Critic::Freenode" => 0,
    "Pod::Weaver::PluginBundle::SHLOMIF" => 0,
    "Pod::Weaver::Section::Support" => 0,
    "Task::FreecellSolver::Testing" => 0,
    "Template" => 0,
    "Template::Stash" => 0,
    "Test::File::Find::CaseCollide" => 0,
    "Test::HTML::Recursive::DeprecatedTags" => 0,
    "Test::Perl::Critic::Policy" => 0,
    "Test::Pod::Coverage" => 0,
    "Text::WrapAsUtf8" => 0,
    "perl" => "5.012",
    "strict" => 0,
    "warnings" => 0
  },
  "test_requires" => {
    "File::Spec" => 0,
    "IO::Handle" => 0,
    "IPC::Open3" => 0,
    "Test::More" => "0.88"
  }
);


my %fallback_build_requires = (
  "File::Spec" => 0,
  "IO::Handle" => 0,
  "IPC::Open3" => 0,
  "Module::Build" => "0.28",
  "Test::More" => "0.88"
);


unless ( eval { Module::Build->VERSION(0.4004) } ) {
  delete $module_build_args{test_requires};
  $module_build_args{build_requires} = \%fallback_build_requires;
}

my $build = Module::Build->new(%module_build_args);


$build->create_build_script;
